==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V1alpha1ClusterRoleBindingFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1ClusterRoleBindingFluent<A extends V1alpha1ClusterRoleBindingFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> editMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildRoleRef instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1RoleRef getRoleRef();
    public V1alpha1RoleRef buildRoleRef();
    public A withRoleRef(V1alpha1RoleRef roleRef);
    public Boolean hasRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> withNewRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> withNewRoleRefLike(V1alpha1RoleRef item);
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> editRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> editOrNewRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> editOrNewRoleRefLike(V1alpha1RoleRef item);
    public A addToSubjects(int index,V1alpha1Subject item);
    public A setToSubjects(int index,V1alpha1Subject item);
    public A addToSubjects(V1alpha1Subject... items);
    public A addAllToSubjects(Collection<V1alpha1Subject> items);
    public A removeFromSubjects(V1alpha1Subject... items);
    public A removeAllFromSubjects(Collection<V1alpha1Subject> items);
    public A removeMatchingFromSubjects(io.kubernetes.client.fluent.Predicate<V1alpha1SubjectBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSubjects instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1Subject> getSubjects();
    public List<V1alpha1Subject> buildSubjects();
    public V1alpha1Subject buildSubject(int index);
    public V1alpha1Subject buildFirstSubject();
    public V1alpha1Subject buildLastSubject();
    public V1alpha1Subject buildMatchingSubject(io.kubernetes.client.fluent.Predicate<V1alpha1SubjectBuilder> predicate);
    public Boolean hasMatchingSubject(io.kubernetes.client.fluent.Predicate<V1alpha1SubjectBuilder> predicate);
    public A withSubjects(List<V1alpha1Subject> subjects);
    public A withSubjects(V1alpha1Subject... subjects);
    public Boolean hasSubjects();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> addNewSubject();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> addNewSubjectLike(V1alpha1Subject item);
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> setNewSubjectLike(int index,V1alpha1Subject item);
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editSubject(int index);
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editFirstSubject();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editLastSubject();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editMatchingSubject(io.kubernetes.client.fluent.Predicate<V1alpha1SubjectBuilder> predicate);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1ClusterRoleBindingFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface RoleRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1RoleRefFluent<V1alpha1ClusterRoleBindingFluent.RoleRefNested<N>>{

        
    public N and();    public N endRoleRef();
}
    public interface SubjectsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1SubjectFluent<V1alpha1ClusterRoleBindingFluent.SubjectsNested<N>>{

        
    public N and();    public N endSubject();
}


}

==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/V1alpha1ClusterRoleBindingFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1ClusterRoleBindingFluent<A extends V1alpha1ClusterRoleBindingFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> editMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1ClusterRoleBindingFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildRoleRef instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1RoleRef getRoleRef();
    public V1alpha1RoleRef buildRoleRef();
    public A withRoleRef(V1alpha1RoleRef roleRef);
    public Boolean hasRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> withNewRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> withNewRoleRefLike(V1alpha1RoleRef item);
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> editRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> editOrNewRoleRef();
    public V1alpha1ClusterRoleBindingFluent.RoleRefNested<A> editOrNewRoleRefLike(V1alpha1RoleRef item);
    public A addToSubjects(int index,RbacV1alpha1Subject item);
    public A setToSubjects(int index,RbacV1alpha1Subject item);
    public A addToSubjects(RbacV1alpha1Subject... items);
    public A addAllToSubjects(Collection<RbacV1alpha1Subject> items);
    public A removeFromSubjects(RbacV1alpha1Subject... items);
    public A removeAllFromSubjects(Collection<RbacV1alpha1Subject> items);
    public A removeMatchingFromSubjects(io.kubernetes.client.fluent.Predicate<RbacV1alpha1SubjectBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildSubjects instead.
 * @return The buildable object.
 */
@Deprecated public List<RbacV1alpha1Subject> getSubjects();
    public List<RbacV1alpha1Subject> buildSubjects();
    public RbacV1alpha1Subject buildSubject(int index);
    public RbacV1alpha1Subject buildFirstSubject();
    public RbacV1alpha1Subject buildLastSubject();
    public RbacV1alpha1Subject buildMatchingSubject(io.kubernetes.client.fluent.Predicate<RbacV1alpha1SubjectBuilder> predicate);
    public Boolean hasMatchingSubject(io.kubernetes.client.fluent.Predicate<RbacV1alpha1SubjectBuilder> predicate);
    public A withSubjects(List<RbacV1alpha1Subject> subjects);
    public A withSubjects(RbacV1alpha1Subject... subjects);
    public Boolean hasSubjects();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> addNewSubject();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> addNewSubjectLike(RbacV1alpha1Subject item);
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> setNewSubjectLike(int index,RbacV1alpha1Subject item);
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editSubject(int index);
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editFirstSubject();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editLastSubject();
    public V1alpha1ClusterRoleBindingFluent.SubjectsNested<A> editMatchingSubject(io.kubernetes.client.fluent.Predicate<RbacV1alpha1SubjectBuilder> predicate);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1ClusterRoleBindingFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface RoleRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1RoleRefFluent<V1alpha1ClusterRoleBindingFluent.RoleRefNested<N>>{

        
    public N and();    public N endRoleRef();
}
    public interface SubjectsNested<N> extends io.kubernetes.client.fluent.Nested<N>,RbacV1alpha1SubjectFluent<V1alpha1ClusterRoleBindingFluent.SubjectsNested<N>>{

        
    public N and();    public N endSubject();
}


}
